@@ -1,6 +1,6 @@
-;;; company-etags.el --- A company-mode completion back-end for etags
+;;; company-etags.el --- company-mode completion back-end for etags
 
-;; Copyright (C) 2009-2011  Free Software Foundation, Inc.
+;; Copyright (C) 2009-2011, 2014  Free Software Foundation, Inc.
 
 ;; Author: Nikolaj Schumacher
 
@@ -25,19 +25,27 @@
 
 ;;; Code:
 
+(eval-when-compile (require 'cl))
 (require 'company)
 (require 'etags)
 
+(defgroup company-etags nil
+  "Completion back-end for etags."
+  :group 'company)
+
 (defcustom company-etags-use-main-table-list t
   "Always search `tags-table-list' if set.
 If this is disabled, `company-etags' will try to find the one table for each
 buffer automatically."
-  :group 'company-mode
   :type '(choice (const :tag "off" nil)
                  (const :tag "on" t)))
 
-(defvar company-etags-modes '(c-mode objc-mode c++-mode java-mode jde-mode
-                              pascal-mode perl-mode python-mode))
+(defcustom company-etags-ignore-case nil
+  "Non-nil to ignore case in completion candidates."
+  :type 'boolean)
+
+(defvar company-etags-modes '(prog-mode c-mode objc-mode c++-mode java-mode
+                              jde-mode pascal-mode perl-mode python-mode))
 
 (defvar company-etags-buffer-table 'unknown)
 (make-variable-buffer-local 'company-etags-buffer-table)
@@ -57,7 +65,7 @@ buffer automatically."
 
 (defun company-etags--candidates (prefix)
   (let ((tags-table-list (company-etags-buffer-table))
-        (completion-ignore-case nil))
+        (completion-ignore-case company-etags-ignore-case))
     (and (or tags-file-name tags-table-list)
          (fboundp 'tags-completion-table)
          (save-excursion
@@ -66,11 +74,11 @@ buffer automatically."
 
 ;;;###autoload
 (defun company-etags (command &optional arg &rest ignored)
-  "A `company-mode' completion back-end for etags."
+  "`company-mode' completion back-end for etags."
   (interactive (list 'interactive))
   (case command
     (interactive (company-begin-backend 'company-etags))
-    (prefix (and (memq major-mode company-etags-modes)
+    (prefix (and (apply 'derived-mode-p company-etags-modes)
                  (not (company-in-string-or-comment))
                  (company-etags-buffer-table)
                  (or (company-grab-symbol) 'stop)))
@@ -79,7 +87,8 @@ buffer automatically."
                 (when (fboundp 'find-tag-noselect)
                   (save-excursion
                     (let ((buffer (find-tag-noselect arg)))
-                      (cons buffer (with-current-buffer buffer (point))))))))))
+                      (cons buffer (with-current-buffer buffer (point))))))))
+    (ignore-case company-etags-ignore-case)))
 
 (provide 'company-etags)
 ;;; company-etags.el ends here
